@@ -6,21 +6,11 @@ from .api_endpoint import ApiEndpoint
 from .api_endpoints import ApiEndpoints
 from .assets import Devices, Users
 from .enforcements import Enforcements
-from .system import (
-    ActivityLogs,
-    Dashboard,
-    Instances,
-    Meta,
-    RemoteSupport,
-    SettingsGlobal,
-    SettingsGui,
-    SettingsIdentityProviders,
-    SettingsLifecycle,
-    Signup,
-    SystemRoles,
-    SystemUsers,
-)
+from .system import (ActivityLogs, Dashboard, Instances, Meta, RemoteSupport,
+                     SettingsGlobal, SettingsGui, SettingsIdentityProviders,
+                     SettingsLifecycle, Signup, SystemRoles, SystemUsers)
 from .wizards import Wizard, WizardCsv, WizardText
+from .openapi import OpenAPISpec
 
 __all__ = (
     "Adapters",
@@ -47,4 +37,5 @@ __all__ = (
     "ApiEndpoints",
     "ApiEndpoint",
     "json_api",
+    "OpenAPISpec",
 )
