@@ -857,11 +857,21 @@ class Cnx(ChildMixins):
             response_json = json_dump(obj=data, error=False)
             response_txt = f"Connectivty test failure, response:\n{response_json}"
 
+            status = data.get("status")
+            etype = data.get("type")
+            emsg = data.get("message")
             errors = listify(data.get("errors"))
 
             exc = None
             pre = ""
 
+            if status == "error":
+                exc = ConfigRequired
+                pre = f"Generic error of type {etype!r} with message: {emsg}"
+                msg = f"{pre} {config_txt}"
+                err = tablize_schemas(schemas=cnx_schemas, err=msg)
+                raise exc(f"{response_txt}\n{err}")
+
             # PBUG: this nasty footwork should be server side
             for error in errors:
                 if not isinstance(error, dict):
@@ -881,7 +891,7 @@ class Cnx(ChildMixins):
             if not exc and data.get("meta") == 400:
                 pre = "Invalid/missing domain or other connection parameter"
                 exc = ConfigRequired
-                # PBUG: with domain=None, {'data': null, 'meta': 400}
+                # PBUG: sometimes returns {'data': null, 'meta': 400}
 
             if exc:
                 msg = f"{pre} {config_txt}"
