@@ -3,7 +3,7 @@
 import click
 
 from ...context import AliasedGroup
-from . import cmd_add, cmd_delete, cmd_get, cmd_get_by_name, cmd_update
+from . import cmd_add, cmd_delete, cmd_get, cmd_get_by_name, cmd_update_name, cmd_update_perms
 
 
 @click.group(cls=AliasedGroup)
@@ -15,4 +15,5 @@ roles.add_command(cmd_get.cmd)
 roles.add_command(cmd_get_by_name.cmd)
 roles.add_command(cmd_delete.cmd)
 roles.add_command(cmd_add.cmd)
-roles.add_command(cmd_update.cmd)
+roles.add_command(cmd_update_name.cmd)
+roles.add_command(cmd_update_perms.cmd)
