@@ -15,7 +15,7 @@ OPTIONS = [
 @add_options(OPTIONS)
 @click.pass_context
 def cmd(ctx, url, key, secret, name, **kwargs):
-    """Get all roles."""
+    """Get a single role."""
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
