@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Constants."""
 from ..setup_env import load_dotenv
-from . import adapters, api, fields, general, logs, system, tables, wizards
+from . import adapters, api, fields, general, logs, tables, wizards
 
 __all__ = (
     "adapters",
@@ -10,7 +10,6 @@ __all__ = (
     "general",
     "logs",
     "wizards",
-    "system",
     "load_dotenv",
     "tables",
 )
