@@ -3,13 +3,13 @@
 import copy
 
 import pytest
-
 from axonius_api_client.api import json_api
-from axonius_api_client.constants.fields import AGG_ADAPTER_ALTS, AGG_ADAPTER_NAME
+from axonius_api_client.constants.fields import (AGG_ADAPTER_ALTS,
+                                                 AGG_ADAPTER_NAME)
 from axonius_api_client.exceptions import ApiError, NotFoundError
 
 from ...meta import FIELD_FORMATS, SCHEMA_FIELD_FORMATS, SCHEMA_TYPES
-from ...utils import get_schemas
+from ...utils import get_schema, get_schemas
 
 
 class FieldsPrivate:
@@ -126,6 +126,10 @@ class FieldsPrivate:
             dvi = field.pop("dynamic_value_identifier", None)
             assert isinstance(dvi, str) or dvi is None
 
+            # 4.3
+            are_values_cached = field.pop("are_values_cached", False)
+            assert isinstance(are_values_cached, bool)
+
             val_source(obj=field)
 
             assert not field, list(field)
@@ -185,6 +189,10 @@ class FieldsPrivate:
             dvi = items.pop("dynamic_value_identifier", None)
             assert isinstance(dvi, str) or dvi is None
 
+            # 4.3
+            are_values_cached = items.pop("are_values_cached", False)
+            assert isinstance(are_values_cached, bool)
+
             assert not items, list(items)
 
             if isinstance(sub_items, dict):
@@ -332,6 +340,10 @@ class FieldsPublic:
         dvi = schema.pop("dynamic_value_identifier", None)
         assert isinstance(dvi, str) or dvi is None
 
+        # 4.3
+        are_values_cached = schema.pop("are_values_cached", False)
+        assert isinstance(are_values_cached, bool)
+
         if is_complex:
             if name != "all":
                 assert sub_fields
@@ -366,6 +378,10 @@ class FieldsPublic:
             dvi = items.pop("dynamic_value_identifier", None)
             assert isinstance(dvi, str) or dvi is None
 
+            # 4.3
+            are_values_cached = items.pop("are_values_cached", False)
+            assert isinstance(are_values_cached, bool)
+
             assert not items
 
         assert not schema, list(schema)
@@ -401,16 +417,21 @@ class FieldsPublic:
     def test_get_field_schema(self, apiobj):
         search = "last_seen"
         schemas = get_schemas(apiobj=apiobj)
-        exp = [x for x in schemas if x["name_base"] == search][0]
+        found = [x for x in schemas if x["name_base"] == search]
+        if not found:
+            pytest.skip(f"field {search} not found")
+        exp = found[0]
         result = apiobj.fields.get_field_schema(value=search, schemas=schemas)
         assert exp == result
 
     def test_get_field_names_re(self, apiobj):
         search = ["seen"]
+        get_schema(apiobj=apiobj, field="specific_data.data.last_seen")
         result = apiobj.fields.get_field_names_re(value=search)
         assert "specific_data.data.last_seen" in result
 
     def test_get_field_names_eq(self, apiobj):
+        get_schema(apiobj=apiobj, field="specific_data.data.last_seen")
         search = ["specific_data.data.id", "last_seen"]
         exp = []
         schemas = get_schemas(apiobj=apiobj)
@@ -502,12 +523,16 @@ class FieldsPublic:
             apiobj.fields.get_field_name(value=search)
 
     def test_get_field_name(self, apiobj):
+        get_schema(apiobj=apiobj, field="specific_data.data.last_seen")
         search = "last_seen"
         exp = "specific_data.data.last_seen"
         result = apiobj.fields.get_field_name(value=search)
         assert result == exp
 
     def test_validate(self, apiobj):
+        get_schema(apiobj=apiobj, field="specific_data.data.last_seen")
+        get_schema(apiobj=apiobj, field="specific_data.data.first_fetch_time")
+
         exp = apiobj.fields_default + [
             "specific_data.data",
             "specific_data.data.first_fetch_time",
@@ -529,7 +554,15 @@ class FieldsPublic:
         result = apiobj.fields.validate()
         assert exp == result
 
+    def test_validate_no_fields_error(self, apiobj):
+        fields = apiobj.fields.validate(fields_default=False, fields_error=False)
+        assert not fields
+
+        fields = apiobj.fields.validate(fields=["xxx"], fields_default=False, fields_error=False)
+        assert fields == ["xxx"]
+
     def test_validate_fuzzy(self, apiobj):
+        get_schema(apiobj=apiobj, field="specific_data.data.last_seen")
         result = apiobj.fields.validate(fields_fuzzy="lastseen", fields_default=False)
         assert "specific_data.data.last_seen" in result
 
